/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.importer.uinfo.importitem;

import java.util.List;

import org.apache.log4j.Logger;
import org.dive4elements.river.importer.common.AbstractSeriesImport;
import org.dive4elements.river.model.River;
import org.dive4elements.river.model.uinfo.Salix;
import org.dive4elements.river.model.uinfo.SalixValue;
import org.hibernate.Query;
import org.hibernate.Session;

/**
 * Imported salix data series of a river
 *
 * @author Matthias Schäfer
 *
 */
public class SalixSeriesImport extends AbstractSeriesImport<Salix, SalixValue, SalixKmLineImport> {

    /***** FIELDS *****/

    private static Logger log = Logger.getLogger(SalixSeriesImport.class);

    private String evaluation_by;


    /***** CONSTRUCTORS *****/

    public SalixSeriesImport(final String filename) {
        super(filename);
    }


    /***** METHODS *****/

    public void setEvaluationBy(final String evaluation_by) {
        this.evaluation_by = evaluation_by;
    }

    @Override
    public Logger getLog() {
        return log;
    }

    @Override
    public List<Salix> querySeriesItem(final Session session, final River river) {
        final Query query = session.createQuery("FROM Salix WHERE river=:river AND lower(filename)=:filename");
        query.setParameter("river", river);
        query.setParameter("filename", this.filename.toLowerCase());
        return query.list();
    }


    @Override
    public Salix createSeriesItem(final River river) {
        return new Salix(river, this.filename, this.kmrange_info, this.comment, this.evaluation_by);
    }
}